Class: Google::Apis::CertificatemanagerV1::CertificateMap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Defines a collection of certificate configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateMap

Returns a new instance of CertificateMap.



420
421
422
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of a Certificate Map. Corresponds to the JSON property createTime

Returns:

  • (String)


383
384
385
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 383

def create_time
  @create_time
end

#descriptionString

Optional. One or more paragraphs of text description of a certificate map. Corresponds to the JSON property description

Returns:

  • (String)


388
389
390
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 388

def description
  @description
end

#gclb_targetsArray<Google::Apis::CertificatemanagerV1::GclbTarget>

Output only. A list of GCLB targets that use this Certificate Map. A Target Proxy is only present on this list if it's attached to a Forwarding Rule. Corresponds to the JSON property gclbTargets



394
395
396
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 394

def gclb_targets
  @gclb_targets
end

#labelsHash<String,String>

Optional. Set of labels associated with a Certificate Map. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


399
400
401
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 399

def labels
  @labels
end

#nameString

Identifier. A user-defined name of the Certificate Map. Certificate Map names must be unique globally and match pattern projects/*/locations/*/ certificateMaps/*. Corresponds to the JSON property name

Returns:

  • (String)


406
407
408
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 406

def name
  @name
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


413
414
415
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 413

def tags
  @tags
end

#update_timeString

Output only. The update timestamp of a Certificate Map. Corresponds to the JSON property updateTime

Returns:

  • (String)


418
419
420
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 418

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



425
426
427
428
429
430
431
432
433
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 425

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gclb_targets = args[:gclb_targets] if args.key?(:gclb_targets)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @tags = args[:tags] if args.key?(:tags)
  @update_time = args[:update_time] if args.key?(:update_time)
end