Class: Google::Apis::CertificatemanagerV1::CertificateMapEntry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Defines a certificate map entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateMapEntry

Returns a new instance of CertificateMapEntry.



492
493
494
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificatesArray<String>

Optional. A set of Certificates defines for the given hostname. There can be defined up to four certificates in each Certificate Map Entry. Each certificate must match pattern projects/*/locations/*/certificates/*. Corresponds to the JSON property certificates

Returns:

  • (Array<String>)


445
446
447
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 445

def certificates
  @certificates
end

#create_timeString

Output only. The creation timestamp of a Certificate Map Entry. Corresponds to the JSON property createTime

Returns:

  • (String)


450
451
452
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 450

def create_time
  @create_time
end

#descriptionString

Optional. One or more paragraphs of text description of a certificate map entry. Corresponds to the JSON property description

Returns:

  • (String)


456
457
458
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 456

def description
  @description
end

#hostnameString

A Hostname (FQDN, e.g. example.com) or a wildcard hostname expression (*. example.com) for a set of hostnames with common suffix. Used as Server Name Indication (SNI) for selecting a proper certificate. Corresponds to the JSON property hostname

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 463

def hostname
  @hostname
end

#labelsHash<String,String>

Optional. Set of labels associated with a Certificate Map Entry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


468
469
470
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 468

def labels
  @labels
end

#matcherString

A predefined matcher for particular cases, other than SNI selection. Corresponds to the JSON property matcher

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 473

def matcher
  @matcher
end

#nameString

Identifier. A user-defined name of the Certificate Map Entry. Certificate Map Entry names must be unique globally and match pattern projects/*/locations/*/ certificateMaps/*/certificateMapEntries/*. Corresponds to the JSON property name

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 480

def name
  @name
end

#stateString

Output only. A serving state of this Certificate Map Entry. Corresponds to the JSON property state

Returns:

  • (String)


485
486
487
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 485

def state
  @state
end

#update_timeString

Output only. The update timestamp of a Certificate Map Entry. Corresponds to the JSON property updateTime

Returns:

  • (String)


490
491
492
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 490

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



497
498
499
500
501
502
503
504
505
506
507
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 497

def update!(**args)
  @certificates = args[:certificates] if args.key?(:certificates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @hostname = args[:hostname] if args.key?(:hostname)
  @labels = args[:labels] if args.key?(:labels)
  @matcher = args[:matcher] if args.key?(:matcher)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end