Class: Google::Apis::CertificatemanagerV1::IPs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

IPs troubleshooting information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IPs

Returns a new instance of IPs.



661
662
663
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resolvedArray<String>

Output only. The list of IP addresses resolved from the domain's A/AAAA records. Can contain both ipv4 and ipv6 addresses. Corresponds to the JSON property resolved

Returns:

  • (Array<String>)


647
648
649
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 647

def resolved
  @resolved
end

#servingArray<String>

Output only. The list of IP addresses, where the certificate is attached and port 443 is open. Corresponds to the JSON property serving

Returns:

  • (Array<String>)


653
654
655
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 653

def serving
  @serving
end

#serving_on_alt_portsArray<String>

Output only. The list of IP addresses, where the certificate is attached, but port 443 is not open. Corresponds to the JSON property servingOnAltPorts

Returns:

  • (Array<String>)


659
660
661
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 659

def serving_on_alt_ports
  @serving_on_alt_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



666
667
668
669
670
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 666

def update!(**args)
  @resolved = args[:resolved] if args.key?(:resolved)
  @serving = args[:serving] if args.key?(:serving)
  @serving_on_alt_ports = args[:serving_on_alt_ports] if args.key?(:serving_on_alt_ports)
end