Class: Google::Apis::CertificatemanagerV1::IntermediateCa
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::IntermediateCa
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
Defines an intermediate CA.
Instance Attribute Summary collapse
-
#pem_certificate ⇒ String
PEM intermediate certificate used for building up paths for validation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntermediateCa
constructor
A new instance of IntermediateCa.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntermediateCa
Returns a new instance of IntermediateCa.
683 684 685 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pem_certificate ⇒ String
PEM intermediate certificate used for building up paths for validation. Each
certificate provided in PEM format may occupy up to 5kB.
Corresponds to the JSON property pemCertificate
681 682 683 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 681 def pem_certificate @pem_certificate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
688 689 690 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 688 def update!(**args) @pem_certificate = args[:pem_certificate] if args.key?(:pem_certificate) end |