Class: Google::Apis::CertificatemanagerV1::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Configuration and state of a Managed Certificate. Certificate Manager provisions and renews Managed Certificates automatically, for as long as it's authorized to do so.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



1097
1098
1099
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorization_attempt_infoArray<Google::Apis::CertificatemanagerV1::AuthorizationAttemptInfo>

Output only. Detailed state of the latest authorization attempt for each domain specified for managed certificate resource. Corresponds to the JSON property authorizationAttemptInfo



1064
1065
1066
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1064

def authorization_attempt_info
  @authorization_attempt_info
end

#dns_authorizationsArray<String>

Optional. Immutable. Authorizations that will be used for performing domain authorization. Corresponds to the JSON property dnsAuthorizations

Returns:

  • (Array<String>)


1070
1071
1072
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1070

def dns_authorizations
  @dns_authorizations
end

#domainsArray<String>

Optional. Immutable. The domains for which a managed SSL certificate will be generated. Wildcard domains are only supported with DNS challenge resolution. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


1076
1077
1078
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1076

def domains
  @domains
end

#issuance_configString

Optional. Immutable. The resource name for a CertificateIssuanceConfig used to configure private PKI certificates in the format projects/*/locations/*/ certificateIssuanceConfigs/*. If this field is not set, the certificates will instead be publicly signed as documented at https://cloud.google.com/load- balancing/docs/ssl-certificates/google-managed-certs#caa. Corresponds to the JSON property issuanceConfig

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1085

def issuance_config
  @issuance_config
end

#provisioning_issueGoogle::Apis::CertificatemanagerV1::ProvisioningIssue

Information about issues with provisioning a Managed Certificate. Corresponds to the JSON property provisioningIssue



1090
1091
1092
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1090

def provisioning_issue
  @provisioning_issue
end

#stateString

Output only. State of the managed certificate resource. Corresponds to the JSON property state

Returns:

  • (String)


1095
1096
1097
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1095

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1102
1103
1104
1105
1106
1107
1108
1109
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1102

def update!(**args)
  @authorization_attempt_info = args[:authorization_attempt_info] if args.key?(:authorization_attempt_info)
  @dns_authorizations = args[:dns_authorizations] if args.key?(:dns_authorizations)
  @domains = args[:domains] if args.key?(:domains)
  @issuance_config = args[:issuance_config] if args.key?(:issuance_config)
  @provisioning_issue = args[:provisioning_issue] if args.key?(:provisioning_issue)
  @state = args[:state] if args.key?(:state)
end