Class: Google::Apis::CertificatemanagerV1::ManagedIdentityCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Configuration and state of a Managed Identity Certificate. Certificate Manager provisions and renews Managed Identity Certificates automatically, for as long as it's authorized to do so.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedIdentityCertificate

Returns a new instance of ManagedIdentityCertificate.



1134
1135
1136
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identityString

Required. Immutable. SPIFFE ID of the Managed Identity used for this certificate. Corresponds to the JSON property identity

Returns:

  • (String)


1122
1123
1124
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1122

def identity
  @identity
end

#provisioning_issueGoogle::Apis::CertificatemanagerV1::ProvisioningIssue

Information about issues with provisioning a Managed Certificate. Corresponds to the JSON property provisioningIssue



1127
1128
1129
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1127

def provisioning_issue
  @provisioning_issue
end

#stateString

Output only. State of the managed certificate resource. Corresponds to the JSON property state

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1132

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1139
1140
1141
1142
1143
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1139

def update!(**args)
  @identity = args[:identity] if args.key?(:identity)
  @provisioning_issue = args[:provisioning_issue] if args.key?(:provisioning_issue)
  @state = args[:state] if args.key?(:state)
end