Class: Google::Apis::CertificatemanagerV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Represents the metadata of the long-running operation. Output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1219
1220
1221
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1183
1184
1185
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1183

def api_version
  @api_version
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1188
1189
1190
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1188

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1193
1194
1195
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1193

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google.longrunning. Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1201
1202
1203
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1201

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1207
1208
1209
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1207

def status_message
  @status_message
end

#targetString

Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1212

def target
  @target
end

#verbString

Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1217
1218
1219
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1217

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1224
1225
1226
1227
1228
1229
1230
1231
1232
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1224

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end