Class: Google::Apis::CertificatemanagerV1::TrustConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Defines a trust config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrustConfig

Returns a new instance of TrustConfig.



1478
1479
1480
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowlisted_certificatesArray<Google::Apis::CertificatemanagerV1::AllowlistedCertificate>

Optional. A certificate matching an allowlisted certificate is always considered valid as long as the certificate is parseable, proof of private key possession is established, and constraints on the certificate's SAN field are met. Corresponds to the JSON property allowlistedCertificates



1422
1423
1424
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1422

def allowlisted_certificates
  @allowlisted_certificates
end

#create_timeString

Output only. The creation timestamp of a TrustConfig. Corresponds to the JSON property createTime

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1427

def create_time
  @create_time
end

#descriptionString

Optional. One or more paragraphs of text description of a TrustConfig. Corresponds to the JSON property description

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1432

def description
  @description
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1439

def etag
  @etag
end

#labelsHash<String,String>

Optional. Set of labels associated with a TrustConfig. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1444
1445
1446
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1444

def labels
  @labels
end

#nameString

Identifier. A user-defined name of the trust config. TrustConfig names must be unique globally and match pattern projects/*/locations/*/trustConfigs/*. Corresponds to the JSON property name

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1450

def name
  @name
end

#spiffe_trust_storesHash<String,Google::Apis::CertificatemanagerV1::TrustStore>

Optional. Defines a mapping from a trust domain to a TrustStore. This is used for SPIFFE certificate validation. Corresponds to the JSON property spiffeTrustStores



1456
1457
1458
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1456

def spiffe_trust_stores
  @spiffe_trust_stores
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1463
1464
1465
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1463

def tags
  @tags
end

#trust_storesArray<Google::Apis::CertificatemanagerV1::TrustStore>

Optional. Set of trust stores to perform validation against. This field is supported when TrustConfig is configured with Load Balancers, currently not supported for SPIFFE certificate validation. Only one TrustStore specified is currently allowed. Corresponds to the JSON property trustStores



1471
1472
1473
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1471

def trust_stores
  @trust_stores
end

#update_timeString

Output only. The last update timestamp of a TrustConfig. Corresponds to the JSON property updateTime

Returns:

  • (String)


1476
1477
1478
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1476

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1483

def update!(**args)
  @allowlisted_certificates = args[:allowlisted_certificates] if args.key?(:allowlisted_certificates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spiffe_trust_stores = args[:spiffe_trust_stores] if args.key?(:spiffe_trust_stores)
  @tags = args[:tags] if args.key?(:tags)
  @trust_stores = args[:trust_stores] if args.key?(:trust_stores)
  @update_time = args[:update_time] if args.key?(:update_time)
end