Class: Google::Apis::CertificatemanagerV1::AuthorizationAttemptInfo
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::AuthorizationAttemptInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
State of the latest attempt to authorize a domain for certificate issuance.
Instance Attribute Summary collapse
-
#attempt_time ⇒ String
Output only.
-
#details ⇒ String
Output only.
-
#domain ⇒ String
Output only.
-
#failure_reason ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#troubleshooting ⇒ Google::Apis::CertificatemanagerV1::Troubleshooting
Troubleshooting information for the authorization attempt.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizationAttemptInfo
constructor
A new instance of AuthorizationAttemptInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizationAttemptInfo
Returns a new instance of AuthorizationAttemptInfo.
81 82 83 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 81 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attempt_time ⇒ String
Output only. The timestamp, when the authorization attempt was made.
Corresponds to the JSON property attemptTime
52 53 54 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 52 def attempt_time @attempt_time end |
#details ⇒ String
Output only. Human readable explanation for reaching the state. Provided to
help address the configuration issues. Not guaranteed to be stable. For
programmatic access use FailureReason enum.
Corresponds to the JSON property details
59 60 61 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 59 def details @details end |
#domain ⇒ String
Output only. Domain name of the authorization attempt.
Corresponds to the JSON property domain
64 65 66 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 64 def domain @domain end |
#failure_reason ⇒ String
Output only. Reason for failure of the authorization attempt for the domain.
Corresponds to the JSON property failureReason
69 70 71 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 69 def failure_reason @failure_reason end |
#state ⇒ String
Output only. State of the domain for managed certificate issuance.
Corresponds to the JSON property state
74 75 76 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 74 def state @state end |
#troubleshooting ⇒ Google::Apis::CertificatemanagerV1::Troubleshooting
Troubleshooting information for the authorization attempt.
Corresponds to the JSON property troubleshooting
79 80 81 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 79 def troubleshooting @troubleshooting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86 87 88 89 90 91 92 93 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 86 def update!(**args) @attempt_time = args[:attempt_time] if args.key?(:attempt_time) @details = args[:details] if args.key?(:details) @domain = args[:domain] if args.key?(:domain) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @state = args[:state] if args.key?(:state) @troubleshooting = args[:troubleshooting] if args.key?(:troubleshooting) end |