Class: Google::Apis::CertificatemanagerV1::Certificate
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::Certificate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
Defines TLS certificate.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#managed ⇒ Google::Apis::CertificatemanagerV1::ManagedCertificate
Configuration and state of a Managed Certificate.
-
#managed_identity ⇒ Google::Apis::CertificatemanagerV1::ManagedIdentityCertificate
Configuration and state of a Managed Identity Certificate.
-
#name ⇒ String
Identifier.
-
#pem_certificate ⇒ String
Output only.
-
#san_dnsnames ⇒ Array<String>
Output only.
-
#scope ⇒ String
Optional.
-
#self_managed ⇒ Google::Apis::CertificatemanagerV1::SelfManagedCertificate
Certificate data for a SelfManaged Certificate.
-
#update_time ⇒ String
Output only.
-
#used_by ⇒ Array<Google::Apis::CertificatemanagerV1::UsedBy>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Certificate
constructor
A new instance of Certificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Certificate
Returns a new instance of Certificate.
224 225 226 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of a Certificate.
Corresponds to the JSON property createTime
152 153 154 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 152 def create_time @create_time end |
#description ⇒ String
Optional. One or more paragraphs of text description of a certificate.
Corresponds to the JSON property description
157 158 159 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 157 def description @description end |
#expire_time ⇒ String
Output only. The expiry timestamp of a Certificate.
Corresponds to the JSON property expireTime
162 163 164 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 162 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with a Certificate.
Corresponds to the JSON property labels
167 168 169 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 167 def labels @labels end |
#managed ⇒ Google::Apis::CertificatemanagerV1::ManagedCertificate
Configuration and state of a Managed Certificate. Certificate Manager
provisions and renews Managed Certificates automatically, for as long as it's
authorized to do so.
Corresponds to the JSON property managed
174 175 176 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 174 def managed @managed end |
#managed_identity ⇒ Google::Apis::CertificatemanagerV1::ManagedIdentityCertificate
Configuration and state of a Managed Identity Certificate. Certificate Manager
provisions and renews Managed Identity Certificates automatically, for as long
as it's authorized to do so.
Corresponds to the JSON property managedIdentity
181 182 183 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 181 def managed_identity @managed_identity end |
#name ⇒ String
Identifier. A user-defined name of the certificate. Certificate names must be
unique globally and match pattern projects/*/locations/*/certificates/*.
Corresponds to the JSON property name
187 188 189 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 187 def name @name end |
#pem_certificate ⇒ String
Output only. The PEM-encoded certificate chain.
Corresponds to the JSON property pemCertificate
192 193 194 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 192 def pem_certificate @pem_certificate end |
#san_dnsnames ⇒ Array<String>
Output only. The list of Subject Alternative Names of dnsName type defined in
the certificate (see RFC 5280 4.2.1.6). Managed certificates that haven't been
provisioned yet have this field populated with a value of the managed.domains
field.
Corresponds to the JSON property sanDnsnames
200 201 202 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 200 def san_dnsnames @san_dnsnames end |
#scope ⇒ String
Optional. Immutable. The scope of the certificate.
Corresponds to the JSON property scope
205 206 207 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 205 def scope @scope end |
#self_managed ⇒ Google::Apis::CertificatemanagerV1::SelfManagedCertificate
Certificate data for a SelfManaged Certificate. SelfManaged Certificates are
uploaded by the user. Updating such certificates before they expire remains
the user's responsibility.
Corresponds to the JSON property selfManaged
212 213 214 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 212 def self_managed @self_managed end |
#update_time ⇒ String
Output only. The last update timestamp of a Certificate.
Corresponds to the JSON property updateTime
217 218 219 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 217 def update_time @update_time end |
#used_by ⇒ Array<Google::Apis::CertificatemanagerV1::UsedBy>
Output only. The list of resources that use this Certificate.
Corresponds to the JSON property usedBy
222 223 224 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 222 def used_by @used_by end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 229 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @managed = args[:managed] if args.key?(:managed) @managed_identity = args[:managed_identity] if args.key?(:managed_identity) @name = args[:name] if args.key?(:name) @pem_certificate = args[:pem_certificate] if args.key?(:pem_certificate) @san_dnsnames = args[:san_dnsnames] if args.key?(:san_dnsnames) @scope = args[:scope] if args.key?(:scope) @self_managed = args[:self_managed] if args.key?(:self_managed) @update_time = args[:update_time] if args.key?(:update_time) @used_by = args[:used_by] if args.key?(:used_by) end |