Class: Google::Apis::CertificatemanagerV1::CertificateIssuanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::CertificateIssuanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
CertificateIssuanceConfig specifies how to issue and manage a certificate.
Instance Attribute Summary collapse
-
#certificate_authority_config ⇒ Google::Apis::CertificatemanagerV1::CertificateAuthorityConfig
The CA that issues the workload certificate.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#key_algorithm ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#lifetime ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#rotation_window_percentage ⇒ Fixnum
Required.
-
#tags ⇒ Hash<String,String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateIssuanceConfig
constructor
A new instance of CertificateIssuanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateIssuanceConfig
Returns a new instance of CertificateIssuanceConfig.
357 358 359 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_authority_config ⇒ Google::Apis::CertificatemanagerV1::CertificateAuthorityConfig
The CA that issues the workload certificate. It includes CA address, type,
authentication to CA service, etc.
Corresponds to the JSON property certificateAuthorityConfig
303 304 305 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 303 def @certificate_authority_config end |
#create_time ⇒ String
Output only. The creation timestamp of a CertificateIssuanceConfig.
Corresponds to the JSON property createTime
308 309 310 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 308 def create_time @create_time end |
#description ⇒ String
Optional. One or more paragraphs of text description of a
CertificateIssuanceConfig.
Corresponds to the JSON property description
314 315 316 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 314 def description @description end |
#key_algorithm ⇒ String
Required. The key algorithm to use when generating the private key.
Corresponds to the JSON property keyAlgorithm
319 320 321 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 319 def key_algorithm @key_algorithm end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with a CertificateIssuanceConfig.
Corresponds to the JSON property labels
324 325 326 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 324 def labels @labels end |
#lifetime ⇒ String
Required. Workload certificate lifetime requested.
Corresponds to the JSON property lifetime
329 330 331 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 329 def lifetime @lifetime end |
#name ⇒ String
Identifier. A user-defined name of the certificate issuance config.
CertificateIssuanceConfig names must be unique globally and match pattern
projects/*/locations/*/certificateIssuanceConfigs/*.
Corresponds to the JSON property name
336 337 338 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 336 def name @name end |
#rotation_window_percentage ⇒ Fixnum
Required. Specifies the percentage of elapsed time of the certificate lifetime
to wait before renewing the certificate. Must be a number between 1-99,
inclusive.
Corresponds to the JSON property rotationWindowPercentage
343 344 345 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 343 def rotation_window_percentage @rotation_window_percentage end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
350 351 352 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 350 def @tags end |
#update_time ⇒ String
Output only. The last update timestamp of a CertificateIssuanceConfig.
Corresponds to the JSON property updateTime
355 356 357 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 355 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 362 def update!(**args) @certificate_authority_config = args[:certificate_authority_config] if args.key?(:certificate_authority_config) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @key_algorithm = args[:key_algorithm] if args.key?(:key_algorithm) @labels = args[:labels] if args.key?(:labels) @lifetime = args[:lifetime] if args.key?(:lifetime) @name = args[:name] if args.key?(:name) @rotation_window_percentage = args[:rotation_window_percentage] if args.key?(:rotation_window_percentage) @tags = args[:tags] if args.key?(:tags) @update_time = args[:update_time] if args.key?(:update_time) end |