Class: Google::Apis::CertificatemanagerV1::Cname
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::Cname
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
CNAME troubleshooting information.
Instance Attribute Summary collapse
-
#expected_data ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#resolved_data ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cname
constructor
A new instance of Cname.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cname
Returns a new instance of Cname.
120 121 122 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expected_data ⇒ String
Output only. The expected value of the CNAME record for the domain, equals to
dns_resource_record.data in the corresponding DnsAuthorization.
Corresponds to the JSON property expectedData
104 105 106 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 104 def expected_data @expected_data end |
#name ⇒ String
Output only. The name of the CNAME record for the domain, equals to
dns_resource_record.name in the corresponding DnsAuthorization.
Corresponds to the JSON property name
110 111 112 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 110 def name @name end |
#resolved_data ⇒ Array<String>
Output only. The resolved CNAME chain. Empty list if the CNAME record for
CNAME.name is not found. Otherwise the first item is the value of the CNAME
record for CNAME.name. If the CNAME chain is longer, the second item is the
value of the CNAME record for the first item, and so on.
Corresponds to the JSON property resolvedData
118 119 120 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 118 def resolved_data @resolved_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
125 126 127 128 129 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 125 def update!(**args) @expected_data = args[:expected_data] if args.key?(:expected_data) @name = args[:name] if args.key?(:name) @resolved_data = args[:resolved_data] if args.key?(:resolved_data) end |