Class: Google::Apis::CertificatemanagerV1::DnsAuthorization

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

A DnsAuthorization resource describes a way to perform domain authorization for certificate issuance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsAuthorization

Returns a new instance of DnsAuthorization.



539
540
541
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of a DnsAuthorization. Corresponds to the JSON property createTime

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 494

def create_time
  @create_time
end

#descriptionString

Optional. One or more paragraphs of text description of a DnsAuthorization. Corresponds to the JSON property description

Returns:

  • (String)


499
500
501
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 499

def description
  @description
end

#dns_resource_recordGoogle::Apis::CertificatemanagerV1::DnsResourceRecord

The structure describing the DNS Resource Record that needs to be added to DNS configuration for the authorization to be usable by certificate. Corresponds to the JSON property dnsResourceRecord



505
506
507
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 505

def dns_resource_record
  @dns_resource_record
end

#domainString

Required. Immutable. A domain that is being authorized. A DnsAuthorization resource covers a single domain and its wildcard, e.g. authorization for example.com can be used to issue certificates for example.com and *. example.com. Corresponds to the JSON property domain

Returns:

  • (String)


513
514
515
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 513

def domain
  @domain
end

#labelsHash<String,String>

Optional. Set of labels associated with a DnsAuthorization. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


518
519
520
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 518

def labels
  @labels
end

#nameString

Identifier. A user-defined name of the dns authorization. DnsAuthorization names must be unique globally and match pattern projects/*/locations/*/ dnsAuthorizations/*. Corresponds to the JSON property name

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 525

def name
  @name
end

#typeString

Optional. Immutable. Type of DnsAuthorization. If unset during resource creation the following default will be used: - in location global: FIXED_RECORD, - in other locations: PER_PROJECT_RECORD. Corresponds to the JSON property type

Returns:

  • (String)


532
533
534
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 532

def type
  @type
end

#update_timeString

Output only. The last update timestamp of a DnsAuthorization. Corresponds to the JSON property updateTime

Returns:

  • (String)


537
538
539
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 537

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



544
545
546
547
548
549
550
551
552
553
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 544

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @dns_resource_record = args[:dns_resource_record] if args.key?(:dns_resource_record)
  @domain = args[:domain] if args.key?(:domain)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end