Class: Google::Apis::CertificatemanagerV1::DnsResourceRecord

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

The structure describing the DNS Resource Record that needs to be added to DNS configuration for the authorization to be usable by certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsResourceRecord

Returns a new instance of DnsResourceRecord.



577
578
579
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Output only. Data of the DNS Resource Record. Corresponds to the JSON property data

Returns:

  • (String)


564
565
566
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 564

def data
  @data
end

#nameString

Output only. Fully qualified name of the DNS Resource Record. e.g. _acme- challenge.example.com Corresponds to the JSON property name

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 570

def name
  @name
end

#typeString

Output only. Type of the DNS Resource Record. Currently always set to "CNAME". Corresponds to the JSON property type

Returns:

  • (String)


575
576
577
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 575

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



582
583
584
585
586
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 582

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end