Class: Google::Apis::CertificatemanagerV1::ManagedCertificate
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::ManagedCertificate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
Configuration and state of a Managed Certificate. Certificate Manager provisions and renews Managed Certificates automatically, for as long as it's authorized to do so.
Instance Attribute Summary collapse
-
#authorization_attempt_info ⇒ Array<Google::Apis::CertificatemanagerV1::AuthorizationAttemptInfo>
Output only.
-
#dns_authorizations ⇒ Array<String>
Optional.
-
#domains ⇒ Array<String>
Optional.
-
#issuance_config ⇒ String
Optional.
-
#provisioning_issue ⇒ Google::Apis::CertificatemanagerV1::ProvisioningIssue
Information about issues with provisioning a Managed Certificate.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedCertificate
constructor
A new instance of ManagedCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedCertificate
Returns a new instance of ManagedCertificate.
1065 1066 1067 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_attempt_info ⇒ Array<Google::Apis::CertificatemanagerV1::AuthorizationAttemptInfo>
Output only. Detailed state of the latest authorization attempt for each
domain specified for managed certificate resource.
Corresponds to the JSON property authorizationAttemptInfo
1032 1033 1034 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1032 def @authorization_attempt_info end |
#dns_authorizations ⇒ Array<String>
Optional. Immutable. Authorizations that will be used for performing domain
authorization.
Corresponds to the JSON property dnsAuthorizations
1038 1039 1040 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1038 def @dns_authorizations end |
#domains ⇒ Array<String>
Optional. Immutable. The domains for which a managed SSL certificate will be
generated. Wildcard domains are only supported with DNS challenge resolution.
Corresponds to the JSON property domains
1044 1045 1046 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1044 def domains @domains end |
#issuance_config ⇒ String
Optional. Immutable. The resource name for a CertificateIssuanceConfig used to
configure private PKI certificates in the format projects/*/locations/*/
certificateIssuanceConfigs/*. If this field is not set, the certificates will
instead be publicly signed as documented at https://cloud.google.com/load-
balancing/docs/ssl-certificates/google-managed-certs#caa.
Corresponds to the JSON property issuanceConfig
1053 1054 1055 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1053 def issuance_config @issuance_config end |
#provisioning_issue ⇒ Google::Apis::CertificatemanagerV1::ProvisioningIssue
Information about issues with provisioning a Managed Certificate.
Corresponds to the JSON property provisioningIssue
1058 1059 1060 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1058 def provisioning_issue @provisioning_issue end |
#state ⇒ String
Output only. State of the managed certificate resource.
Corresponds to the JSON property state
1063 1064 1065 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1063 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1070 def update!(**args) @authorization_attempt_info = args[:authorization_attempt_info] if args.key?(:authorization_attempt_info) @dns_authorizations = args[:dns_authorizations] if args.key?(:dns_authorizations) @domains = args[:domains] if args.key?(:domains) @issuance_config = args[:issuance_config] if args.key?(:issuance_config) @provisioning_issue = args[:provisioning_issue] if args.key?(:provisioning_issue) @state = args[:state] if args.key?(:state) end |