Class: Google::Apis::CertificatemanagerV1::ManagedIdentityCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Configuration and state of a Managed Identity Certificate. Certificate Manager provisions and renews Managed Identity Certificates automatically, for as long as it's authorized to do so.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedIdentityCertificate

Returns a new instance of ManagedIdentityCertificate.



1102
1103
1104
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identityString

Required. Immutable. SPIFFE ID of the Managed Identity used for this certificate. Corresponds to the JSON property identity

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1090

def identity
  @identity
end

#provisioning_issueGoogle::Apis::CertificatemanagerV1::ProvisioningIssue

Information about issues with provisioning a Managed Certificate. Corresponds to the JSON property provisioningIssue



1095
1096
1097
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1095

def provisioning_issue
  @provisioning_issue
end

#stateString

Output only. State of the managed certificate resource. Corresponds to the JSON property state

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1100

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1107
1108
1109
1110
1111
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1107

def update!(**args)
  @identity = args[:identity] if args.key?(:identity)
  @provisioning_issue = args[:provisioning_issue] if args.key?(:provisioning_issue)
  @state = args[:state] if args.key?(:state)
end