Class: Google::Apis::CertificatemanagerV1::TrustConfig
- Inherits:
-
Object
- Object
- Google::Apis::CertificatemanagerV1::TrustConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb
Overview
Defines a trust config.
Instance Attribute Summary collapse
-
#allowlisted_certificates ⇒ Array<Google::Apis::CertificatemanagerV1::AllowlistedCertificate>
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#spiffe_trust_stores ⇒ Hash<String,Google::Apis::CertificatemanagerV1::TrustStore>
Optional.
-
#trust_stores ⇒ Array<Google::Apis::CertificatemanagerV1::TrustStore>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrustConfig
constructor
A new instance of TrustConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrustConfig
Returns a new instance of TrustConfig.
1439 1440 1441 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowlisted_certificates ⇒ Array<Google::Apis::CertificatemanagerV1::AllowlistedCertificate>
Optional. A certificate matching an allowlisted certificate is always
considered valid as long as the certificate is parseable, proof of private key
possession is established, and constraints on the certificate's SAN field are
met.
Corresponds to the JSON property allowlistedCertificates
1390 1391 1392 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1390 def allowlisted_certificates @allowlisted_certificates end |
#create_time ⇒ String
Output only. The creation timestamp of a TrustConfig.
Corresponds to the JSON property createTime
1395 1396 1397 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1395 def create_time @create_time end |
#description ⇒ String
Optional. One or more paragraphs of text description of a TrustConfig.
Corresponds to the JSON property description
1400 1401 1402 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1400 def description @description end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
1407 1408 1409 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1407 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with a TrustConfig.
Corresponds to the JSON property labels
1412 1413 1414 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1412 def labels @labels end |
#name ⇒ String
Identifier. A user-defined name of the trust config. TrustConfig names must be
unique globally and match pattern projects/*/locations/*/trustConfigs/*.
Corresponds to the JSON property name
1418 1419 1420 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1418 def name @name end |
#spiffe_trust_stores ⇒ Hash<String,Google::Apis::CertificatemanagerV1::TrustStore>
Optional. Defines a mapping from a trust domain to a TrustStore. This is used
for SPIFFE certificate validation.
Corresponds to the JSON property spiffeTrustStores
1424 1425 1426 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1424 def spiffe_trust_stores @spiffe_trust_stores end |
#trust_stores ⇒ Array<Google::Apis::CertificatemanagerV1::TrustStore>
Optional. Set of trust stores to perform validation against. This field is
supported when TrustConfig is configured with Load Balancers, currently not
supported for SPIFFE certificate validation. Only one TrustStore specified is
currently allowed.
Corresponds to the JSON property trustStores
1432 1433 1434 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1432 def trust_stores @trust_stores end |
#update_time ⇒ String
Output only. The last update timestamp of a TrustConfig.
Corresponds to the JSON property updateTime
1437 1438 1439 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1437 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1444 def update!(**args) @allowlisted_certificates = args[:allowlisted_certificates] if args.key?(:allowlisted_certificates) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spiffe_trust_stores = args[:spiffe_trust_stores] if args.key?(:spiffe_trust_stores) @trust_stores = args[:trust_stores] if args.key?(:trust_stores) @update_time = args[:update_time] if args.key?(:update_time) end |