Class: Google::Apis::CertificatemanagerV1::TrustStore

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/certificatemanager_v1/classes.rb,
lib/google/apis/certificatemanager_v1/representations.rb,
lib/google/apis/certificatemanager_v1/representations.rb

Overview

Defines a trust store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrustStore

Returns a new instance of TrustStore.



1474
1475
1476
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intermediate_casArray<Google::Apis::CertificatemanagerV1::IntermediateCa>

Optional. Set of intermediate CA certificates used for the path building phase of chain validation. The field is currently not supported if TrustConfig is used for the workload certificate feature. Corresponds to the JSON property intermediateCas



1466
1467
1468
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1466

def intermediate_cas
  @intermediate_cas
end

#trust_anchorsArray<Google::Apis::CertificatemanagerV1::TrustAnchor>

Optional. List of Trust Anchors to be used while performing validation against a given TrustStore. Corresponds to the JSON property trustAnchors



1472
1473
1474
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1472

def trust_anchors
  @trust_anchors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1479
1480
1481
1482
# File 'lib/google/apis/certificatemanager_v1/classes.rb', line 1479

def update!(**args)
  @intermediate_cas = args[:intermediate_cas] if args.key?(:intermediate_cas)
  @trust_anchors = args[:trust_anchors] if args.key?(:trust_anchors)
end